@@ -5,7 +5,7 @@ This example is to demonstrate GooeyPy's widgets and functionality.
 import sys
 sys.path.insert(0, "..")
 
-from gooeypy import sdl as gui
+import gooeypy as gui
 import pygame
 from gooeypy.const import *
 
@@ -107,7 +107,7 @@ w1.connect(CLICK, callback)
 # Now lets run our app!
 quit = False
 while not quit:
-    clock.tick(40)
+    clock.tick(30)
 
     # We do this so we can share the events with the gui.
     events = pygame.event.get()
