@@ -5,6 +5,11 @@
 import util
 
 
+try:
+    set # Only available in Python 2.4+
+except NameError:
+    from sets import Set as set # Python 2.3 fallback
+
 
 class Pulsate:
     """
@@ -18,25 +23,32 @@ class Pulsate:
     def __init__(self, speed):
         self.speed = speed
         self.t = False
-        self.alpha = 255
+        self.alpha = None
+
+        # We allow for multiple surfaces because a widget will have one for each
+        # event (hover etc) that will need to be animated
         self.used_surfs = set()
 
+        self.orig_alpha = None
+
     def run(self, surf):
-        #print self.alpha
+        if not self.orig_alpha:
+            self.orig_alpha = surf.get_alpha() or 255
+            self.alpha = self.orig_alpha
         self.used_surfs.add(surf)
         surf.set_alpha(self.alpha)
-        if self.alpha <= 150: self.t = True
+        min_alpha = max(30, self.orig_alpha-150)
+        if self.alpha <= min_alpha: self.t = True
 
         if not self.t:
             surf.set_alpha(self.alpha-self.speed)
             self.alpha -= self.speed
-        elif self.alpha < 255:
+        elif self.alpha < self.orig_alpha:
             surf.set_alpha(self.alpha+self.speed)
             self.alpha += self.speed
         else:
-            # All done. Clean up and set all used surfs to full opacy.
+            # All done. Clean up and set all used surfs to original opacy.
             for s  in self.used_surfs:
-                # FIXME: needs to set to original alpha.
-                s.set_alpha(255)
+                s.set_alpha(self.orig_alpha)
             return False
         return surf
\ No newline at end of file
